@@ -1,24 +1,41 @@
 import logging
+import sys
 from datetime import datetime
-from logging import CRITICAL, DEBUG, ERROR, INFO, NOTSET, WARNING
+from logging import CRITICAL, DEBUG, ERROR, INFO, WARNING
+from pathlib import Path
 from threading import Lock
+from typing import IO, List, Optional, Union
 
+
+FORMAT_STYLE = "{"
+FORMAT_BASE = "[{name}][{levelname}] {message}"
+FORMAT_DATE = "%H:%M:%S"
+REMOVE_BASE = ["streamlink", "streamlink_cli"]
+
+# Make NONE ("none") the highest possible level that suppresses all log messages:
+#  `logging.NOTSET` (equal to 0) can't be used as the "none" level because of `logging.Logger.getEffectiveLevel()`, which
+#  loops through the logger instance's ancestor chain and checks whether the instance's level is NOTSET. If it is NOTSET,
+#  then it continues with the parent logger, which means that if the level of `streamlink.logger.root` was set to "none" and
+#  its value NOTSET, then it would continue with `logging.root` whose default level is `logging.WARNING` (equal to 30).
+NONE = sys.maxsize
+# Add "trace" to Streamlink's log levels
 TRACE = 5
-_levelToName = {
+
+# Define Streamlink's log levels (and register both lowercase and uppercase names)
+_levelToNames = {
+    NONE: "none",
     CRITICAL: "critical",
     ERROR: "error",
     WARNING: "warning",
     INFO: "info",
     DEBUG: "debug",
     TRACE: "trace",
-    NOTSET: "none",
 }
-_nameToLevel = {name: level for level, name in _levelToName.items()}
 
-for level, name in _levelToName.items():
-    logging.addLevelName(level, name)
+for _level, _name in _levelToNames.items():
+    logging.addLevelName(_level, _name.upper())
+    logging.addLevelName(_level, _name)
 
-levels = [name for _, name in _levelToName.items()]
 _config_lock = Lock()
 
 
@@ -60,40 +77,50 @@ class StringFormatter(logging.Formatter):
         return super().format(record)
 
 
-def basicConfig(**kwargs) -> logging.StreamHandler:
+# noinspection PyShadowingBuiltins,PyPep8Naming
+def basicConfig(
+    filename: Optional[Union[str, Path]] = None,
+    filemode: str = "a",
+    stream: Optional[IO] = None,
+    level: Optional[str] = None,
+    format: str = FORMAT_BASE,
+    style: str = FORMAT_STYLE,
+    datefmt: str = FORMAT_DATE,
+    remove_base: Optional[List[str]] = None
+) -> Union[logging.FileHandler, logging.StreamHandler]:
     with _config_lock:
-        filename = kwargs.get("filename")
-        if filename:
-            mode = kwargs.get("filemode", "a")
-            handler = logging.FileHandler(filename, mode)
+        if filename is not None:
+            handler = logging.FileHandler(filename, filemode)
         else:
-            stream = kwargs.get("stream")
             handler = logging.StreamHandler(stream)
-        fs = kwargs.get("format", BASIC_FORMAT)
-        style = kwargs.get("style", FORMAT_STYLE)
-        dfs = kwargs.get("datefmt", FORMAT_DATE)
-        remove_base = kwargs.get("remove_base", REMOVE_BASE)
 
-        formatter = StringFormatter(fs, dfs, style=style, remove_base=remove_base)
+        formatter = StringFormatter(
+            format,
+            datefmt,
+            style=style,
+            remove_base=remove_base or REMOVE_BASE
+        )
         handler.setFormatter(formatter)
 
         root.addHandler(handler)
-        level = kwargs.get("level")
         if level is not None:
             root.setLevel(level)
 
     return handler
 
 
-BASIC_FORMAT = "[{name}][{levelname}] {message}"
-FORMAT_STYLE = "{"
-FORMAT_DATE = "%H:%M:%S"
-REMOVE_BASE = ["streamlink", "streamlink_cli"]
-
-
 logging.setLoggerClass(StreamlinkLogger)
 root = logging.getLogger("streamlink")
 root.setLevel(WARNING)
 
+levels = list(_levelToNames.values())
 
-__all__ = ["StreamlinkLogger", "TRACE", "basicConfig", "root", "levels"]
+
+__all__ = [
+    "NONE",
+    "TRACE",
+    "StreamlinkLogger",
+    "basicConfig",
+    "root",
+    "levels",
+]
