@@ -1,9 +1,9 @@
 import logging
 import re
 
-from streamlink.plugin import Plugin
-from streamlink.stream import HLSStream
-from streamlink.utils import parse_json
+from streamlink.plugin import Plugin, pluginmatcher
+from streamlink.stream.hls import HLSStream
+from streamlink.utils.parse import parse_json
 
 log = logging.getLogger(__name__)
 
@@ -15,16 +15,14 @@ QUALITIES = {
     "240p": "_240"
 }
 
-_url_re = re.compile(r"https?://(?:www\.)?goodgame.ru/channel/(?P<user>[^/]+)")
 _apidata_re = re.compile(r'''(?P<quote>["']?)channel(?P=quote)\s*:\s*(?P<data>{.*?})\s*,''')
 _ddos_re = re.compile(r'document.cookie="(__DDOS_[^;]+)')
 
 
+@pluginmatcher(re.compile(
+    r"https?://(?:www\.)?goodgame\.ru/channel/(?P<user>[^/]+)"
+))
 class GoodGame(Plugin):
-    @classmethod
-    def can_handle_url(cls, url):
-        return _url_re.match(url)
-
     def _check_stream(self, url):
         res = self.session.http.get(url, acceptable_status=(200, 404))
         if res.status_code == 200:
