@@ -2,22 +2,20 @@ import logging
 import re
 from urllib.parse import parse_qsl
 
-from streamlink.plugin import Plugin
-from streamlink.stream import HTTPStream
+from streamlink.plugin import Plugin, pluginmatcher
+from streamlink.stream.http import HTTPStream
 
 log = logging.getLogger(__name__)
 
 
+@pluginmatcher(re.compile(
+    r"https?://(?:drive|docs)\.google\.com/file/d/([^/]+)/?"
+))
 class GoogleDocs(Plugin):
-    url_re = re.compile(r"https?://(?:drive|docs)\.google\.com/file/d/([^/]+)/?")
     api_url = "https://docs.google.com/get_video_info"
 
-    @classmethod
-    def can_handle_url(cls, url):
-        return cls.url_re.match(url) is not None
-
     def _get_streams(self):
-        docid = self.url_re.match(self.url).group(1)
+        docid = self.match.group(1)
         log.debug("Google Docs ID: {0}".format(docid))
         res = self.session.http.get(self.api_url, params=dict(docid=docid))
         data = dict(parse_qsl(res.text))
