@@ -1,22 +1,19 @@
 import logging
 import re
 
-from streamlink.plugin import Plugin
-from streamlink.stream import HLSStream
+from streamlink.plugin import Plugin, pluginmatcher
+from streamlink.stream.hls import HLSStream
 
 log = logging.getLogger(__name__)
 
 
+@pluginmatcher(re.compile(
+    r'https?://(?:www\.)?tlctv\.com\.tr/canli-izle'
+))
 class TLCtr(Plugin):
-
-    _url_re = re.compile(r'https?://(?:www\.)?tlctv\.com\.tr/canli-izle')
     _hls_re = re.compile(
         r'''["'](?P<url>https?://[^/]+/live/hls/[^"']+)["']''')
 
-    @classmethod
-    def can_handle_url(cls, url):
-        return cls._url_re.match(url) is not None
-
     def _get_streams(self):
         res = self.session.http.get(self.url)
 
