@@ -1,12 +1,14 @@
 import re
 
-from streamlink.plugin import Plugin
+from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
-from streamlink.stream import HLSStream
+from streamlink.stream.hls import HLSStream
 
 
+@pluginmatcher(re.compile(
+    r"https?://(?:www\.)?tv360\.com\.tr/canli-yayin"
+))
 class TV360(Plugin):
-    url_re = re.compile(r"https?://(?:www\.)?tv360\.com\.tr/canli-yayin")
     hls_re = re.compile(r'''src="(http.*m3u8)"''')
 
     hls_schema = validate.Schema(
@@ -14,10 +16,6 @@ class TV360(Plugin):
         validate.any(None, validate.all(validate.get(1), validate.url()))
     )
 
-    @classmethod
-    def can_handle_url(cls, url):
-        return cls.url_re.match(url) is not None
-
     def _get_streams(self):
         hls_url = self.session.http.get(self.url, schema=self.hls_schema)
 
