@@ -12,9 +12,12 @@ class TestPluginCanHandleUrlMPEGDASH(PluginCanHandleUrl):
     __plugin__ = MPEGDASH
 
     should_match = [
+        "example.com/foo.mpd",
         "http://example.com/foo.mpd",
-        "dash://http://www.testing.cat/directe",
-        "dash://https://www.testing.cat/directe",
+        "https://example.com/foo.mpd",
+        "dash://example.com/foo",
+        "dash://http://example.com/foo",
+        "dash://https://example.com/foo",
     ]
 
 
@@ -30,6 +33,23 @@ def test_priority(url, priority):
     assert next((matcher.priority for matcher in MPEGDASH.matchers if matcher.pattern.match(url)), NO_PRIORITY) == priority
 
 
+@pytest.mark.parametrize("url,expected", [
+    ("example.com/foo.mpd", "https://example.com/foo.mpd"),
+    ("http://example.com/foo.mpd", "http://example.com/foo.mpd"),
+    ("https://example.com/foo.mpd", "https://example.com/foo.mpd"),
+    ("dash://example.com/foo", "https://example.com/foo"),
+    ("dash://http://example.com/foo", "http://example.com/foo"),
+    ("dash://https://example.com/foo", "https://example.com/foo"),
+])
+@patch("streamlink.stream.DASHStream.parse_manifest")
+def test_get_streams(parse_manifest, url, expected):
+    session = Mock()
+    MPEGDASH.bind(session, "tests.plugins.test_dash")
+    p = MPEGDASH(url)
+    p.streams()
+    parse_manifest.assert_called_with(session, expected)
+
+
 class TestPluginMPEGDASH(unittest.TestCase):
     def test_stream_weight(self):
         self.assertAlmostEqual(MPEGDASH.stream_weight("720p"), (720, 'pixels'))
@@ -37,19 +57,3 @@ class TestPluginMPEGDASH(unittest.TestCase):
         self.assertAlmostEqual(MPEGDASH.stream_weight("720p+a128k"), (720 + 128, 'pixels'))
         self.assertAlmostEqual(MPEGDASH.stream_weight("720p+a0k"), (720, 'pixels'))
         self.assertAlmostEqual(MPEGDASH.stream_weight("a128k"), (128 / BIT_RATE_WEIGHT_RATIO, 'bitrate'))
-
-    @patch("streamlink.stream.DASHStream.parse_manifest")
-    def test_get_streams_prefix(self, parse_manifest):
-        session = Mock()
-        MPEGDASH.bind(session, "tests.plugins.test_dash")
-        p = MPEGDASH("dash://http://example.com/foo.mpd")
-        p.streams()
-        parse_manifest.assert_called_with(session, "http://example.com/foo.mpd")
-
-    @patch("streamlink.stream.DASHStream.parse_manifest")
-    def test_get_streams(self, parse_manifest):
-        session = Mock()
-        MPEGDASH.bind(session, "tests.plugins.test_dash")
-        p = MPEGDASH("http://example.com/foo.mpd")
-        p.streams()
-        parse_manifest.assert_called_with(session, "http://example.com/foo.mpd")
