@@ -6,8 +6,15 @@ class TestPluginCanHandleUrlEuronews(PluginCanHandleUrl):
     __plugin__ = GOLTelevision
 
     should_match = [
-        "http://www.goltelevision.com/live",
+        "http://goltelevision.com/en-directo",
+        "http://www.goltelevision.com/en-directo",
+        "https://goltelevision.com/en-directo",
+        "https://www.goltelevision.com/en-directo",
+    ]
+
+    should_not_match = [
         "http://goltelevision.com/live",
+        "http://www.goltelevision.com/live",
         "https://goltelevision.com/live",
         "https://www.goltelevision.com/live",
     ]
