@@ -9,7 +9,11 @@ class TestPluginCanHandleUrlMediaVitrina(PluginCanHandleUrl):
         "https://chetv.ru/online/",
         "https://ctc.ru/online/",
         "https://ctclove.ru/online/",
+        "https://domashniy.ru/online",
         "https://ren.tv/live",
+        "https://www.5-tv.ru/live/",
+        "https://www.5-tv.ru/online/",
+        # player.mediavitrina.ru
         "https://player.mediavitrina.ru/5tv/moretv_web/player.html",
         "https://player.mediavitrina.ru/che/che_web/player.html",
         "https://player.mediavitrina.ru/ctc_ext/moretv_web/player.html",
@@ -18,12 +22,14 @@ class TestPluginCanHandleUrlMediaVitrina(PluginCanHandleUrl):
         "https://player.mediavitrina.ru/ctc/ctcmedia_web/player.html?start=auto",
         "https://player.mediavitrina.ru/domashniy_ext/moretv_web/player.html",
         "https://player.mediavitrina.ru/domashniy/dom_web/player.html?start=auto",
+        "https://player.mediavitrina.ru/gpm_tv3_v2/tv3/smotrim_web/611632488a33a/player.html",
         "https://player.mediavitrina.ru/iz/moretv_web/player.html",
         "https://player.mediavitrina.ru/kultura/limehd_web/player.html",
         "https://player.mediavitrina.ru/kultura/moretv_web/player.html",
         "https://player.mediavitrina.ru/mir/mir/moretv_web/player.html",
         "https://player.mediavitrina.ru/muztv/moretv_web/player.html",
         "https://player.mediavitrina.ru/rentv/moretv_web/player.html",
+        "https://player.mediavitrina.ru/russia1/mailru_web/player.html",
         "https://player.mediavitrina.ru/russia1/moretv_web/player.html",
         "https://player.mediavitrina.ru/russia24/moretv_web/player.html",
         "https://player.mediavitrina.ru/russia24/vesti_ru_web/player.html?id",
