@@ -10,4 +10,6 @@ class TestPluginCanHandleUrlNicoLive(PluginCanHandleUrl):
         'http://live2.nicovideo.jp/watch/lv534562961',
         'https://live.nicovideo.jp/watch/lv534562961',
         'https://live2.nicovideo.jp/watch/lv534562961?ref=rtrec&zroute=recent',
+        'https://live.nicovideo.jp/watch/co2467009?ref=community',
+        'https://live.nicovideo.jp/watch/co2619719',
     ]
