@@ -6,13 +6,13 @@ class TestPluginCanHandleUrlTV999(PluginCanHandleUrl):
     __plugin__ = TV999
 
     should_match = [
-        'http://tv999.bg/live.html',
-        'http://www.tv999.bg/live.html',
-        'https://tv999.bg/live.html',
-        'https://www.tv999.bg/live.html',
+        "http://tv999.bg/live.html",
+        "http://www.tv999.bg/live.html",
+        "https://tv999.bg/live"
+        "https://tv999.bg/live.html",
+        "https://www.tv999.bg/live.html",
     ]
 
     should_not_match = [
-        'http://tv999.bg/',
-        'https://tv999.bg/live',
+        "http://tv999.bg/",
     ]
