@@ -1,7 +1,7 @@
-from unittest.mock import Mock
-
 import pytest
+import requests_mock as rm
 
+from streamlink import Streamlink
 from streamlink.exceptions import NoStreamsError
 from streamlink.plugins.vk import VK
 from tests.plugins import PluginCanHandleUrl
@@ -20,40 +20,54 @@ class TestPluginCanHandleUrlVK(PluginCanHandleUrl):
         "https://vk.com/video132886594_167211693",
         "https://vk.com/videos132886594?z=video132886594_167211693",
         "https://vk.com/video-73154028_456239128",
+        "https://vk.com/dota2?w=wall-126093223_1057924",
+        "https://vk.com/search?c%5Bq%5D=dota&c%5Bsection%5D=auto&z=video295508334_171402661",
     ]
 
     should_not_match = [
         "https://vk.com/",
-        "https://vk.com/restore",
     ]
 
 
 @pytest.mark.parametrize("url,newurl,raises", [
-    ("https://vk.com/videos-24136539?z=video-24136539_456241176%2Fclub24136539%2Fpl_-24136539_-2",
+    # canonical video URL
+    ("https://vk.com/video-24136539_456241176",
      "https://vk.com/video-24136539_456241176",
      False),
+
+    # video ID from URL
     ("https://vk.com/videos-24136539?z=video-24136539_456241181%2Fpl_-24136539_-2",
      "https://vk.com/video-24136539_456241181",
      False),
     ("https://vk.com/videos132886594?z=video132886594_167211693",
      "https://vk.com/video132886594_167211693",
      False),
-    ("http://vk.com/",
-     "http://vk.com/",
+    ("https://vk.com/search?c%5Bq%5D=dota&c%5Bsection%5D=auto&z=video295508334_171402661",
+     "https://vk.com/video295508334_171402661",
      False),
-    ("http://vk.com/videos-24136539",
-     "http://vk.com/videos-24136539",
+
+    # video ID from HTTP request
+    ("https://vk.com/dota2?w=wall-126093223_1057924",
+     "https://vk.com/video-126093223_1057924",
+     False),
+
+    # no video ID
+    ("https://vk.com/videos-0123456789?z=",
+     "",
      True),
-    ("http://vk.com/videos-24136539?z=",
-     "http://vk.com/videos-24136539?z=",
+    ("https://vk.com/video/for_kids?z=video%2Fpl_-22277933_51053000",
+     "",
      True),
 ])
-def test_url_redirect(url, newurl, raises):
-    VK.bind(Mock(), "tests.plugins.test_vk")
+def test_url_redirect(url, newurl, raises, requests_mock):
+    session = Streamlink()
+    VK.bind(session, "tests.plugins.test_vk")
     plugin = VK(url)
+    requests_mock.register_uri(rm.ANY, rm.ANY, exc=rm.exceptions.InvalidRequest)
+    requests_mock.get(url, text=f"""<!DOCTYPE html><html><head><meta property="og:url" content="{newurl}"/></head></html>""")
     try:
         plugin.follow_vk_redirect()
         assert not raises
+        assert plugin.url == newurl
     except NoStreamsError:
         assert raises
-    assert plugin.url == newurl
