@@ -73,10 +73,10 @@ class TestCommandLinePOSIX(CommandLineTestCase):
                         ["/usr/bin/player", "--input-title-format", 'Poker "Stars"', "-"])
 
     def test_open_player_extra_args_in_player_pass_through(self):
-        self._test_args(["streamlink", "--player-passthrough", "rtmp", "-p", "/usr/bin/player",
+        self._test_args(["streamlink", "--player-passthrough", "hls", "-p", "/usr/bin/player",
                          "-a", '''--input-title-format "Poker \\"Stars\\"" {filename}''',
-                         "test.se", "rtmp"],
-                        ["/usr/bin/player", "--input-title-format", 'Poker "Stars"', "rtmp://test.se"],
+                         "test.se", "hls"],
+                        ["/usr/bin/player", "--input-title-format", 'Poker "Stars"', "http://test.se/playlist.m3u8"],
                         passthrough=True)
 
     def test_single_hyphen_extra_player_args_971(self):
@@ -114,10 +114,11 @@ class TestCommandLineWindows(CommandLineTestCase):
                         '''c:\\Program Files\\Player\\player.exe --input-title-format "Poker \\"Stars\\"" -''')
 
     def test_open_player_extra_args_in_player_pass_through(self):
-        self._test_args(["streamlink", "--player-passthrough", "rtmp", "-p", "c:\\Program Files\\Player\\player.exe",
+        self._test_args(["streamlink", "--player-passthrough", "hls", "-p", "c:\\Program Files\\Player\\player.exe",
                          "-a", '''--input-title-format "Poker \\"Stars\\"" {filename}''',
-                         "test.se", "rtmp"],
-                        '''c:\\Program Files\\Player\\player.exe --input-title-format "Poker \\"Stars\\"" \"rtmp://test.se\"''',
+                         "test.se", "hls"],
+                        '''c:\\Program Files\\Player\\player.exe'''
+                        + ''' --input-title-format "Poker \\"Stars\\"" \"http://test.se/playlist.m3u8\"''',
                         passthrough=True)
 
     def test_single_hyphen_extra_player_args_971(self):
