@@ -208,7 +208,7 @@ class TestPluginMatcher(unittest.TestCase):
         self.assertEqual(plugin.match, None)
 
 
-@pytest.mark.parametrize("attr", ["author", "category", "title"])
+@pytest.mark.parametrize("attr", ["id", "author", "category", "title"])
 def test_plugin_metadata(attr):
     plugin = FakePlugin("https://foo.bar/")
     getter = getattr(plugin, f"get_{attr}")
