@@ -4,11 +4,13 @@ import unittest
 from socket import AF_INET, AF_INET6
 from unittest.mock import Mock, call, patch
 
+import requests_mock
 from requests.packages.urllib3.util.connection import allowed_gai_family
 
 from streamlink import NoPluginError, Streamlink
 from streamlink.plugin import HIGH_PRIORITY, LOW_PRIORITY, NORMAL_PRIORITY, NO_PRIORITY, Plugin, pluginmatcher
-from streamlink.stream import AkamaiHDStream, HLSStream, HTTPStream, RTMPStream
+from streamlink.stream.hls import HLSStream
+from streamlink.stream.http import HTTPStream
 
 
 class EmptyPlugin(Plugin):
@@ -17,8 +19,19 @@ class EmptyPlugin(Plugin):
 
 
 class TestSession(unittest.TestCase):
+    mocker: requests_mock.Mocker
+
     plugin_path = os.path.join(os.path.dirname(__file__), "plugin")
 
+    def setUp(self):
+        self.mocker = requests_mock.Mocker()
+        self.mocker.register_uri(requests_mock.ANY, requests_mock.ANY, text="")
+        self.mocker.start()
+
+    def tearDown(self):
+        self.mocker.stop()
+        Streamlink.resolve_url.cache_clear()
+
     def subject(self, load_plugins=True):
         session = Streamlink()
         if load_plugins:
@@ -26,9 +39,18 @@ class TestSession(unittest.TestCase):
 
         return session
 
-    def test_exceptions(self):
-        session = self.subject()
-        self.assertRaises(NoPluginError, session.resolve_url, "invalid url", follow_redirect=False)
+    @staticmethod
+    def _resolve_url(method, *args, **kwargs) -> Plugin:
+        pluginclass, resolved_url = method(*args, **kwargs)
+        return pluginclass(resolved_url)
+
+    def resolve_url(self, session: Streamlink, url: str, *args, **kwargs) -> Plugin:
+        return self._resolve_url(session.resolve_url, url, *args, **kwargs)
+
+    def resolve_url_no_redirect(self, session: Streamlink, url: str, *args, **kwargs) -> Plugin:
+        return self._resolve_url(session.resolve_url_no_redirect, url, *args, **kwargs)
+
+    # ----
 
     def test_load_plugins(self):
         session = self.subject()
@@ -73,32 +95,89 @@ class TestSession(unittest.TestCase):
     def test_resolve_url(self):
         session = self.subject()
         plugins = session.get_plugins()
-        plugin = session.resolve_url("http://test.se/channel")
-        self.assertTrue(isinstance(plugin, Plugin))
-        self.assertTrue(isinstance(plugin, plugins["testplugin"]))
+
+        pluginclass, resolved_url = session.resolve_url("http://test.se/channel")
+        self.assertTrue(issubclass(pluginclass, Plugin))
+        self.assertIs(pluginclass, plugins["testplugin"])
+        self.assertEqual(resolved_url, "http://test.se/channel")
         self.assertTrue(hasattr(session.resolve_url, "cache_info"), "resolve_url has a lookup cache")
 
+    def test_resolve_url__noplugin(self):
+        session = self.subject()
+        self.mocker.get("http://invalid2", status_code=301, headers={"Location": "http://invalid3"})
+
+        self.assertRaises(NoPluginError, session.resolve_url, "http://invalid1")
+        self.assertRaises(NoPluginError, session.resolve_url, "http://invalid2")
+
+    def test_resolve_url__redirected(self):
+        session = self.subject()
+        plugins = session.get_plugins()
+        self.mocker.head("http://redirect1", status_code=501)
+        self.mocker.get("http://redirect1", status_code=301, headers={"Location": "http://redirect2"})
+        self.mocker.head("http://redirect2", status_code=301, headers={"Location": "http://test.se/channel"})
+
+        pluginclass, resolved_url = session.resolve_url("http://redirect1")
+        self.assertTrue(issubclass(pluginclass, Plugin))
+        self.assertIs(pluginclass, plugins["testplugin"])
+        self.assertEqual(resolved_url, "http://test.se/channel")
+
+    def test_resolve_url_no_redirect(self):
+        session = self.subject()
+        plugins = session.get_plugins()
+
+        pluginclass, resolved_url = session.resolve_url_no_redirect("http://test.se/channel")
+        self.assertTrue(issubclass(pluginclass, Plugin))
+        self.assertIs(pluginclass, plugins["testplugin"])
+        self.assertEqual(resolved_url, "http://test.se/channel")
+
+    def test_resolve_url_no_redirect__noplugin(self):
+        session = self.subject()
+        self.assertRaises(NoPluginError, session.resolve_url_no_redirect, "http://invalid")
+
+    def test_resolve_url_scheme(self):
+        @pluginmatcher(re.compile("http://insecure"))
+        class PluginHttp(EmptyPlugin):
+            pass
+
+        @pluginmatcher(re.compile("https://secure"))
+        class PluginHttps(EmptyPlugin):
+            pass
+
+        session = self.subject(load_plugins=False)
+        session.plugins = {
+            "insecure": PluginHttp,
+            "secure": PluginHttps,
+        }
+
+        self.assertRaises(NoPluginError, self.resolve_url, session, "insecure")
+        self.assertIsInstance(self.resolve_url(session, "http://insecure"), PluginHttp)
+        self.assertRaises(NoPluginError, self.resolve_url, session, "https://insecure")
+
+        self.assertIsInstance(self.resolve_url(session, "secure"), PluginHttps)
+        self.assertRaises(NoPluginError, self.resolve_url, session, "http://secure")
+        self.assertIsInstance(self.resolve_url(session, "https://secure"), PluginHttps)
+
     def test_resolve_url_priority(self):
         @pluginmatcher(priority=HIGH_PRIORITY, pattern=re.compile(
-            "http://(high|normal|low|no)$"
+            "https://(high|normal|low|no)$"
         ))
         class HighPriority(EmptyPlugin):
             pass
 
         @pluginmatcher(priority=NORMAL_PRIORITY, pattern=re.compile(
-            "http://(normal|low|no)$"
+            "https://(normal|low|no)$"
         ))
         class NormalPriority(EmptyPlugin):
             pass
 
         @pluginmatcher(priority=LOW_PRIORITY, pattern=re.compile(
-            "http://(low|no)$"
+            "https://(low|no)$"
         ))
         class LowPriority(EmptyPlugin):
             pass
 
         @pluginmatcher(priority=NO_PRIORITY, pattern=re.compile(
-            "http://(no)$"
+            "https://(no)$"
         ))
         class NoPriority(EmptyPlugin):
             pass
@@ -110,10 +189,10 @@ class TestSession(unittest.TestCase):
             "low": LowPriority,
             "no": NoPriority,
         }
-        no = session.resolve_url_no_redirect("no")
-        low = session.resolve_url_no_redirect("low")
-        normal = session.resolve_url_no_redirect("normal")
-        high = session.resolve_url_no_redirect("high")
+        no = self.resolve_url_no_redirect(session, "no")
+        low = self.resolve_url_no_redirect(session, "low")
+        normal = self.resolve_url_no_redirect(session, "normal")
+        high = self.resolve_url_no_redirect(session, "high")
 
         self.assertIsInstance(no, HighPriority)
         self.assertIsInstance(low, HighPriority)
@@ -125,12 +204,12 @@ class TestSession(unittest.TestCase):
             "no": NoPriority,
         }
         with self.assertRaises(NoPluginError):
-            session.resolve_url_no_redirect("no")
+            self.resolve_url_no_redirect(session, "no")
 
     @patch("streamlink.session.log")
     def test_resolve_deprecated(self, mock_log: Mock):
         @pluginmatcher(priority=LOW_PRIORITY, pattern=re.compile(
-            "http://low"
+            "https://low"
         ))
         class LowPriority(EmptyPlugin):
             pass
@@ -156,19 +235,12 @@ class TestSession(unittest.TestCase):
             "dep-high": DeprecatedHighPriority,
         }
 
-        self.assertIsInstance(session.resolve_url_no_redirect("low"), DeprecatedHighPriority)
+        self.assertIsInstance(self.resolve_url_no_redirect(session, "low"), DeprecatedHighPriority)
         self.assertEqual(mock_log.info.mock_calls, [
             call("Resolved plugin dep-normal-one with deprecated can_handle_url API"),
             call("Resolved plugin dep-high with deprecated can_handle_url API")
         ])
 
-    def test_resolve_url_no_redirect(self):
-        session = self.subject()
-        plugin = session.resolve_url_no_redirect("http://test.se/channel")
-        plugins = session.get_plugins()
-        self.assertTrue(isinstance(plugin, Plugin))
-        self.assertTrue(isinstance(plugin, plugins["testplugin"]))
-
     def test_options(self):
         session = self.subject()
         session.set_option("test_option", "option")
@@ -183,34 +255,32 @@ class TestSession(unittest.TestCase):
 
     def test_plugin(self):
         session = self.subject()
-        plugin = session.resolve_url("http://test.se/channel")
+        plugin = self.resolve_url(session, "http://test.se/channel")
         streams = plugin.streams()
 
         self.assertTrue("best" in streams)
         self.assertTrue("worst" in streams)
         self.assertTrue(streams["best"] is streams["1080p"])
         self.assertTrue(streams["worst"] is streams["350k"])
-        self.assertTrue(isinstance(streams["rtmp"], RTMPStream))
         self.assertTrue(isinstance(streams["http"], HTTPStream))
         self.assertTrue(isinstance(streams["hls"], HLSStream))
-        self.assertTrue(isinstance(streams["akamaihd"], AkamaiHDStream))
 
     def test_plugin_stream_types(self):
         session = self.subject()
-        plugin = session.resolve_url("http://test.se/channel")
-        streams = plugin.streams(stream_types=["http", "rtmp"])
+        plugin = self.resolve_url(session, "http://test.se/channel")
+        streams = plugin.streams(stream_types=["http", "hls"])
 
         self.assertTrue(isinstance(streams["480p"], HTTPStream))
-        self.assertTrue(isinstance(streams["480p_rtmp"], RTMPStream))
+        self.assertTrue(isinstance(streams["480p_hls"], HLSStream))
 
-        streams = plugin.streams(stream_types=["rtmp", "http"])
+        streams = plugin.streams(stream_types=["hls", "http"])
 
-        self.assertTrue(isinstance(streams["480p"], RTMPStream))
+        self.assertTrue(isinstance(streams["480p"], HLSStream))
         self.assertTrue(isinstance(streams["480p_http"], HTTPStream))
 
     def test_plugin_stream_sorting_excludes(self):
         session = self.subject()
-        plugin = session.resolve_url("http://test.se/channel")
+        plugin = self.resolve_url(session, "http://test.se/channel")
 
         streams = plugin.streams(sorting_excludes=[])
         self.assertTrue("best" in streams)
@@ -242,7 +312,7 @@ class TestSession(unittest.TestCase):
         self.assertTrue(streams["worst-unfiltered"] is streams["350k"])
         self.assertTrue(streams["best-unfiltered"] is streams["1080p"])
 
-        plugin = session.resolve_url("http://test.se/UnsortableStreamNames")
+        plugin = self.resolve_url(session, "http://test.se/UnsortableStreamNames")
         streams = plugin.streams()
         self.assertFalse("best" in streams)
         self.assertFalse("worst" in streams)
@@ -259,12 +329,12 @@ class TestSession(unittest.TestCase):
         self.assertEqual(session.localization.language.alpha2, "en")
         self.assertEqual(session.localization.language_code, "en_US")
 
-    @patch("streamlink.session.api")
-    def test_interface(self, mock_api):
+    @patch("streamlink.session.HTTPSession")
+    def test_interface(self, mock_httpsession):
         adapter_http = Mock(poolmanager=Mock(connection_pool_kw={}))
         adapter_https = Mock(poolmanager=Mock(connection_pool_kw={}))
         adapter_foo = Mock(poolmanager=Mock(connection_pool_kw={}))
-        mock_api.HTTPSession.return_value = Mock(adapters={
+        mock_httpsession.return_value = Mock(adapters={
             "http://": adapter_http,
             "https://": adapter_https,
             "foo://": adapter_foo
@@ -332,19 +402,33 @@ class TestSession(unittest.TestCase):
         session.set_option("http-proxy", "http://testproxy.com")
 
         self.assertEqual("http://testproxy.com", session.http.proxies['http'])
-        self.assertEqual("https://testhttpsproxy.com", session.http.proxies['https'])
+        self.assertEqual("http://testproxy.com", session.http.proxies['https'])
 
     def test_https_proxy_default_override(self):
         session = self.subject(load_plugins=False)
         session.set_option("http-proxy", "http://testproxy.com")
         session.set_option("https-proxy", "https://testhttpsproxy.com")
 
-        self.assertEqual("http://testproxy.com", session.http.proxies['http'])
+        self.assertEqual("https://testhttpsproxy.com", session.http.proxies['http'])
         self.assertEqual("https://testhttpsproxy.com", session.http.proxies['https'])
 
     def test_https_proxy_set_only(self):
         session = self.subject(load_plugins=False)
         session.set_option("https-proxy", "https://testhttpsproxy.com")
 
-        self.assertFalse("http" in session.http.proxies)
+        self.assertEqual("https://testhttpsproxy.com", session.http.proxies['http'])
         self.assertEqual("https://testhttpsproxy.com", session.http.proxies['https'])
+
+    def test_http_proxy_socks(self):
+        session = self.subject(load_plugins=False)
+        session.set_option("http-proxy", "socks5://localhost:1234")
+
+        self.assertEqual("socks5://localhost:1234", session.http.proxies["http"])
+        self.assertEqual("socks5://localhost:1234", session.http.proxies["https"])
+
+    def test_https_proxy_socks(self):
+        session = self.subject(load_plugins=False)
+        session.set_option("https-proxy", "socks5://localhost:1234")
+
+        self.assertEqual("socks5://localhost:1234", session.http.proxies["http"])
+        self.assertEqual("socks5://localhost:1234", session.http.proxies["https"])
